@@ -115,11 +115,17 @@
             element => "Specify the elements names of this configuration class.",
             include => "Include the specification of another class into this class.",
             include_after => "insert the included elements after a specific element",
-            class_description => "Explain the purpose of this configuration class. This description will be re-used to generate the documentation of your configuration class",
+            class_description => "Explain the purpose of this configuration class. This description will be re-used to generate the documentation of your configuration class. You can use pod markup to format your description. See L<perlpod> for details.",
             read_config => "Specify the Perl class(es) and function(s) used to read configuration data. The specified function will be tried in sequence to get configuration data. ",
             write_config => "Specify the Perl class and function used to write configuration data.",
             generated_by => "When set, this class was generated by some program. You should not edit it as your modification may be clobbered later on",
-            accept => "Specifies names of the elements this configuration class will accept as valid (based on a regular expression)"
+            accept => "Specifies names of the elements this configuration class will accept as valid. "
+                ."The key of the hash is a regular expression that will be tested against 
+           candidate parameters. When the parameter matches the regular expression, 
+           a new parameter is created in the model using the description provided
+           in the value of this hash key. Note that the regexp must match the whole 
+           candidate parameter name. I.e. the specified regexp will be eval\'ed 
+           with a leading ^ and a trailing \$."
         ],
     ],
 
@@ -240,7 +246,7 @@
                 refer_to   => '- - element',
                 level      => 'hidden',
                 description =>
-'Sometimes, the structure of a file loaded by Augeas starts directly with a list of items. For instance, /etc/hosts structure starts with a list of lines that specify hosts and IP adresses. This parameter specifies an element name in Config::Model root class that will hold the configuration data retrieved by Augeas',
+'Sometimes, the structure of a file loaded by Augeas starts directly with a list of items. For instance, /etc/hosts structure starts with a list of lines that specify hosts and IP addresses. This parameter specifies an element name in Config::Model root class that will hold the configuration data retrieved by Augeas',
                 warp => {
                     follow => '- backend',
                     rules  => [ augeas => { level => 'normal', } ],
@@ -360,7 +366,6 @@
 
         ],
     ],
-
     [
         name => 'Itself::ConfigAccept',
 
@@ -370,18 +375,9 @@
             'name_match' => {
                 type             => 'leaf',
                 value_type       => 'uniline',
-                level            => 'normal',
                 upstream_default => '.*',
-                summary => 'Accepted parameters must match this regexp',
-                description =>
-                  'Define a Perl regular expression that is tested agaisnt 
-           candidate parameters. When the parameter matches the regular expression, 
-           a new parameter is created in the model using the description provided
-           within the "accept" declaration. Note that the regexp must match the whole 
-           candidate parameter name. I.e. the specified regexp will be eval\'ed 
-           with a leading ^ and a trailing $. Without a specification, all parameters
-           are accepted',
-            },
+                status           => 'deprecated',
+             },
 
         ],
     ],
